@@ -7,6 +7,8 @@
 #ifndef IRECORDWRITER_H
 #define IRECORDWRITER_H
 
+#include "pbbam/Config.h"
+
 namespace PacBio {
 namespace BAM {
 
@@ -16,7 +18,7 @@ class BamRecordImpl;
 class IRecordWriter
 {
 public:
-    virtual ~IRecordWriter() = default;
+    virtual ~IRecordWriter();
 
 public:
     /// \brief Try to flush any buffered data to file.
@@ -46,7 +48,7 @@ public:
     virtual void Write(const BamRecordImpl& recordImpl) = 0;
 
 protected:
-    IRecordWriter() = default;
+    IRecordWriter();
 };
 
 }  // namespace BAM
