@@ -3,6 +3,8 @@
 #ifndef PBBAM_VCF_VCFWRITER_H
 #define PBBAM_VCF_VCFWRITER_H
 
+#include "pbbam/Config.h"
+
 #include <memory>
 #include <string>
 
@@ -17,11 +19,8 @@ class VcfWriter
 public:
     VcfWriter(std::string filename, const VcfHeader& header);
 
-    VcfWriter() = delete;
-    VcfWriter(const VcfWriter&) = delete;
-    VcfWriter(VcfWriter&&) = default;
-    VcfWriter& operator=(const VcfWriter&) = delete;
-    VcfWriter& operator=(VcfWriter&&) = default;
+    VcfWriter(VcfWriter&&) noexcept;
+    VcfWriter& operator=(VcfWriter&&) noexcept;
     ~VcfWriter();
 
 public:
