@@ -4,13 +4,14 @@
 
 #include "pbbam/BamRecordImpl.h"
 
-#include <algorithm>
-#include <array>
 #include <cassert>
 #include <cstddef>
 #include <cstdint>
 #include <cstdlib>
 #include <cstring>
+
+#include <algorithm>
+#include <array>
 #include <iostream>
 #include <tuple>
 #include <utility>
@@ -18,38 +19,16 @@
 #include <htslib/hts_endian.h>
 
 #include "pbbam/BamTagCodec.h"
+#include "pbbam/StringUtilities.h"
 
 #include "BamRecordTags.h"
 #include "MemoryUtils.h"
-#include "StringUtils.h"
 
 namespace PacBio {
 namespace BAM {
 
 namespace {
 
-static bool DoesHtslibSupportLongCigar()
-{
-    const std::string htsVersion = hts_version();
-
-    // remove any "-<blah>" for non-release versions
-    const auto versionBase = PacBio::BAM::Split(htsVersion, '-');
-    if (versionBase.empty())
-        throw std::runtime_error{"invalid htslib version format: " + htsVersion};
-
-    // grab major/minor version numbers
-    const auto versionParts = PacBio::BAM::Split(versionBase[0], '.');
-    if (versionParts.size() < 2)
-        throw std::runtime_error{"invalid htslib version format: " + htsVersion};
-
-    // check against v1.7
-    const int versionMajor = std::stoi(versionParts[0]);
-    const int versionMinor = std::stoi(versionParts[1]);
-    static constexpr const int v17_major = 1;
-    static constexpr const int v17_minor = 7;
-    return std::tie(versionMajor, versionMinor) >= std::tie(v17_major, v17_minor);
-}
-
 static const bool has_native_long_cigar_support = DoesHtslibSupportLongCigar();
 
 Cigar FetchRawCigar(const uint32_t* const src, const uint32_t len)
@@ -92,27 +71,20 @@ bool HasLongCigar(const bam1_t* const b)
     return true;
 }
 
-}  // namespace anonymous
+}  // namespace
 
-BamRecordImpl::BamRecordImpl() : d_(nullptr)
+BamRecordImpl::BamRecordImpl() : d_{nullptr}
 {
     InitializeData();
     assert(d_);
 }
 
 BamRecordImpl::BamRecordImpl(const BamRecordImpl& other)
-    : d_{bam_dup1(other.d_.get()), internal::HtslibRecordDeleter()}, tagOffsets_{other.tagOffsets_}
+    : d_{bam_dup1(other.d_.get()), HtslibRecordDeleter()}, tagOffsets_{other.tagOffsets_}
 {
     assert(d_);
 }
 
-BamRecordImpl::BamRecordImpl(BamRecordImpl&& other) : tagOffsets_{std::move(other.tagOffsets_)}
-{
-    d_.swap(other.d_);
-    other.d_.reset();
-    assert(d_);
-}
-
 BamRecordImpl& BamRecordImpl::operator=(const BamRecordImpl& other)
 {
     if (this != &other) {
@@ -124,18 +96,6 @@ BamRecordImpl& BamRecordImpl::operator=(const BamRecordImpl& other)
     return *this;
 }
 
-BamRecordImpl& BamRecordImpl::operator=(BamRecordImpl&& other)
-{
-    if (this != &other) {
-        d_.swap(other.d_);
-        other.d_.reset();
-
-        tagOffsets_ = std::move(other.tagOffsets_);
-    }
-    assert(d_);
-    return *this;
-}
-
 bool BamRecordImpl::AddTag(const std::string& tagName, const Tag& value)
 {
     return AddTag(tagName, value, TagModifier::NONE);
@@ -143,7 +103,7 @@ bool BamRecordImpl::AddTag(const std::string& tagName, const Tag& value)
 
 bool BamRecordImpl::AddTag(const BamRecordTag tag, const Tag& value)
 {
-    return AddTag(internal::BamRecordTags::LabelFor(tag), value, TagModifier::NONE);
+    return AddTag(BamRecordTags::LabelFor(tag), value, TagModifier::NONE);
 }
 
 bool BamRecordImpl::AddTag(const std::string& tagName, const Tag& value,
@@ -158,7 +118,7 @@ bool BamRecordImpl::AddTag(const std::string& tagName, const Tag& value,
 bool BamRecordImpl::AddTag(const BamRecordTag tag, const Tag& value,
                            const TagModifier additionalModifier)
 {
-    return AddTag(internal::BamRecordTags::LabelFor(tag), value, additionalModifier);
+    return AddTag(BamRecordTags::LabelFor(tag), value, additionalModifier);
 }
 
 bool BamRecordImpl::AddTagImpl(const std::string& tagName, const Tag& value,
@@ -172,6 +132,14 @@ bool BamRecordImpl::AddTagImpl(const std::string& tagName, const Tag& value,
     return true;
 }
 
+uint32_t BamRecordImpl::Bin() const { return d_->core.bin; }
+
+BamRecordImpl& BamRecordImpl::Bin(uint32_t bin)
+{
+    d_->core.bin = bin;
+    return *this;
+}
+
 Cigar BamRecordImpl::CigarData() const
 {
     const auto* b = d_.get();
@@ -232,7 +200,7 @@ bool BamRecordImpl::EditTag(const std::string& tagName, const Tag& newValue)
 
 bool BamRecordImpl::EditTag(const BamRecordTag tag, const Tag& newValue)
 {
-    return EditTag(internal::BamRecordTags::LabelFor(tag), newValue, TagModifier::NONE);
+    return EditTag(BamRecordTags::LabelFor(tag), newValue, TagModifier::NONE);
 }
 
 bool BamRecordImpl::EditTag(const std::string& tagName, const Tag& newValue,
@@ -251,7 +219,15 @@ bool BamRecordImpl::EditTag(const std::string& tagName, const Tag& newValue,
 bool BamRecordImpl::EditTag(const BamRecordTag tag, const Tag& newValue,
                             const TagModifier additionalModifier)
 {
-    return EditTag(internal::BamRecordTags::LabelFor(tag), newValue, additionalModifier);
+    return EditTag(BamRecordTags::LabelFor(tag), newValue, additionalModifier);
+}
+
+uint32_t BamRecordImpl::Flag() const { return d_->core.flag; }
+
+BamRecordImpl& BamRecordImpl::Flag(uint32_t flag)
+{
+    d_->core.flag = flag;
+    return *this;
 }
 
 BamRecordImpl BamRecordImpl::FromRawData(const std::shared_ptr<bam1_t>& rawData)
@@ -265,19 +241,16 @@ bool BamRecordImpl::HasTag(const std::string& tagName) const
 {
     if (tagName.size() != 2) return false;
     return TagOffset(tagName) != -1;
-
-    // 27635
-    //    return bam_aux_get(d_.get(), tagName.c_str()) != 0;
 }
 
 bool BamRecordImpl::HasTag(const BamRecordTag tag) const
 {
-    return HasTag(internal::BamRecordTags::LabelFor(tag));
+    return HasTag(BamRecordTags::LabelFor(tag));
 }
 
 void BamRecordImpl::InitializeData()
 {
-    d_.reset(bam_init1(), internal::HtslibRecordDeleter());
+    d_.reset(bam_init1(), HtslibRecordDeleter());
     d_->data = static_cast<uint8_t*>(
         calloc(0x800, sizeof(uint8_t)));  // maybe make this value tune-able later?
     d_->m_data = 0x800;
@@ -296,6 +269,105 @@ void BamRecordImpl::InitializeData()
     d_->l_data = 4;
 }
 
+int32_t BamRecordImpl::InsertSize() const { return d_->core.isize; }
+
+BamRecordImpl& BamRecordImpl::InsertSize(int32_t iSize)
+{
+    d_->core.isize = iSize;
+    return *this;
+}
+
+bool BamRecordImpl::IsDuplicate() const { return (d_->core.flag & BamRecordImpl::DUPLICATE) != 0; }
+
+bool BamRecordImpl::IsFailedQC() const { return (d_->core.flag & BamRecordImpl::FAILED_QC) != 0; }
+
+bool BamRecordImpl::IsFirstMate() const { return (d_->core.flag & BamRecordImpl::MATE_1) != 0; }
+
+bool BamRecordImpl::IsMapped() const { return (d_->core.flag & BamRecordImpl::UNMAPPED) == 0; }
+
+bool BamRecordImpl::IsMateMapped() const
+{
+    return (d_->core.flag & BamRecordImpl::MATE_UNMAPPED) == 0;
+}
+
+bool BamRecordImpl::IsMateReverseStrand() const
+{
+    return (d_->core.flag & BamRecordImpl::MATE_REVERSE_STRAND) != 0;
+}
+
+bool BamRecordImpl::IsPaired() const { return (d_->core.flag & BamRecordImpl::PAIRED) != 0; }
+
+bool BamRecordImpl::IsPrimaryAlignment() const
+{
+    return (d_->core.flag & BamRecordImpl::SECONDARY) == 0;
+}
+
+bool BamRecordImpl::IsProperPair() const
+{
+    return (d_->core.flag & BamRecordImpl::PROPER_PAIR) != 0;
+}
+
+bool BamRecordImpl::IsReverseStrand() const
+{
+    return (d_->core.flag & BamRecordImpl::REVERSE_STRAND) != 0;
+}
+
+bool BamRecordImpl::IsSecondMate() const { return (d_->core.flag & BamRecordImpl::MATE_2) != 0; }
+
+bool BamRecordImpl::IsSupplementaryAlignment() const
+{
+    return (d_->core.flag & BamRecordImpl::SUPPLEMENTARY) != 0;
+}
+
+uint8_t BamRecordImpl::MapQuality() const { return d_->core.qual; }
+
+BamRecordImpl& BamRecordImpl::MapQuality(uint8_t mapQual)
+{
+    d_->core.qual = mapQual;
+    return *this;
+}
+
+PacBio::BAM::Position BamRecordImpl::MatePosition() const { return d_->core.mpos; }
+
+BamRecordImpl& BamRecordImpl::MatePosition(PacBio::BAM::Position pos)
+{
+    d_->core.mpos = pos;
+    return *this;
+}
+
+int32_t BamRecordImpl::MateReferenceId() const { return d_->core.mtid; }
+
+BamRecordImpl& BamRecordImpl::MateReferenceId(int32_t id)
+{
+    d_->core.mtid = id;
+    return *this;
+}
+
+PacBio::BAM::Position BamRecordImpl::Position() const { return d_->core.pos; }
+
+BamRecordImpl& BamRecordImpl::Position(PacBio::BAM::Position pos)
+{
+    d_->core.pos = pos;
+    return *this;
+}
+
+int32_t BamRecordImpl::ReferenceId() const { return d_->core.tid; }
+
+BamRecordImpl& BamRecordImpl::ReferenceId(int32_t id)
+{
+    d_->core.tid = id;
+    return *this;
+}
+
+BamRecordImpl& BamRecordImpl::SetDuplicate(bool ok)
+{
+    if (ok)
+        d_->core.flag |= BamRecordImpl::DUPLICATE;
+    else
+        d_->core.flag &= ~BamRecordImpl::DUPLICATE;
+    return *this;
+}
+
 void BamRecordImpl::MaybeReallocData()
 {
     // about to grow data contents to l_data size, but m_data is our current max.
@@ -366,7 +438,7 @@ bool BamRecordImpl::RemoveTag(const std::string& tagName)
 
 bool BamRecordImpl::RemoveTag(const BamRecordTag tag)
 {
-    return RemoveTag(internal::BamRecordTags::LabelFor(tag));
+    return RemoveTag(BamRecordTags::LabelFor(tag));
 }
 
 bool BamRecordImpl::RemoveTagImpl(const std::string& tagName)
@@ -417,12 +489,107 @@ void BamRecordImpl::SetCigarData(const Cigar& cigar)
     }
 }
 
+BamRecordImpl& BamRecordImpl::SetFailedQC(bool ok)
+{
+    if (ok)
+        d_->core.flag |= BamRecordImpl::FAILED_QC;
+    else
+        d_->core.flag &= ~BamRecordImpl::FAILED_QC;
+    return *this;
+}
+
+BamRecordImpl& BamRecordImpl::SetFirstMate(bool ok)
+{
+    if (ok)
+        d_->core.flag |= BamRecordImpl::MATE_1;
+    else
+        d_->core.flag &= ~BamRecordImpl::MATE_1;
+    return *this;
+}
+
+BamRecordImpl& BamRecordImpl::SetMapped(bool ok)
+{
+    if (ok)
+        d_->core.flag &= ~BamRecordImpl::UNMAPPED;
+    else
+        d_->core.flag |= BamRecordImpl::UNMAPPED;
+    return *this;
+}
+
+BamRecordImpl& BamRecordImpl::SetMateMapped(bool ok)
+{
+    if (ok)
+        d_->core.flag &= ~BamRecordImpl::MATE_UNMAPPED;
+    else
+        d_->core.flag |= BamRecordImpl::MATE_UNMAPPED;
+    return *this;
+}
+
+BamRecordImpl& BamRecordImpl::SetMateReverseStrand(bool ok)
+{
+    if (ok)
+        d_->core.flag |= BamRecordImpl::MATE_REVERSE_STRAND;
+    else
+        d_->core.flag &= ~BamRecordImpl::MATE_REVERSE_STRAND;
+    return *this;
+}
+
+BamRecordImpl& BamRecordImpl::SetPaired(bool ok)
+{
+    if (ok)
+        d_->core.flag |= BamRecordImpl::PAIRED;
+    else
+        d_->core.flag &= ~BamRecordImpl::PAIRED;
+    return *this;
+}
+
+BamRecordImpl& BamRecordImpl::SetPrimaryAlignment(bool ok)
+{
+    if (ok)
+        d_->core.flag &= ~BamRecordImpl::SECONDARY;
+    else
+        d_->core.flag |= BamRecordImpl::SECONDARY;
+    return *this;
+}
+
+BamRecordImpl& BamRecordImpl::SetProperPair(bool ok)
+{
+    if (ok)
+        d_->core.flag |= BamRecordImpl::PROPER_PAIR;
+    else
+        d_->core.flag &= ~BamRecordImpl::PROPER_PAIR;
+    return *this;
+}
+
+BamRecordImpl& BamRecordImpl::SetReverseStrand(bool ok)
+{
+    if (ok)
+        d_->core.flag |= BamRecordImpl::REVERSE_STRAND;
+    else
+        d_->core.flag &= ~BamRecordImpl::REVERSE_STRAND;
+    return *this;
+}
+
+BamRecordImpl& BamRecordImpl::SetSecondMate(bool ok)
+{
+    if (ok)
+        d_->core.flag |= BamRecordImpl::MATE_2;
+    else
+        d_->core.flag &= ~BamRecordImpl::MATE_2;
+    return *this;
+}
+
 BamRecordImpl& BamRecordImpl::SetSequenceAndQualities(const std::string& sequence,
                                                       const std::string& qualities)
 {
-    if (!qualities.empty() && (sequence.size() != qualities.size()))
-        throw std::runtime_error{"If QUAL provided, must be of the same length as SEQ"};
-
+    if (!qualities.empty() && (sequence.size() != qualities.size())) {
+        std::ostringstream s;
+        s << "[pbbam] BAM record ERROR: if qualities are provided, the length must match the "
+             "sequence length:\n"
+          << "  sequence length: " << sequence.size() << '\n'
+          << "  qualities length: " << qualities.size();
+        throw std::runtime_error{s.str()};
+    }
     return SetSequenceAndQualitiesInternal(sequence.c_str(), sequence.size(), qualities.c_str(),
                                            false);
 }
@@ -487,9 +654,20 @@ BamRecordImpl& BamRecordImpl::SetSequenceAndQualitiesInternal(const char* sequen
     return *this;
 }
 
+BamRecordImpl& BamRecordImpl::SetSupplementaryAlignment(bool ok)
+{
+    if (ok)
+        d_->core.flag |= BamRecordImpl::SUPPLEMENTARY;
+    else
+        d_->core.flag &= ~BamRecordImpl::SUPPLEMENTARY;
+    return *this;
+}
+
 int BamRecordImpl::TagOffset(const std::string& tagName) const
 {
-    if (tagName.size() != 2) throw std::runtime_error{"invalid tag name size"};
+    if (tagName.size() != 2)
+        throw std::runtime_error{"[pbbam] BAM record ERROR: tag name (" + tagName +
+                                 ") must have 2 characters only"};
 
     if (tagOffsets_.empty()) UpdateTagMap();
 
@@ -547,7 +725,7 @@ Tag BamRecordImpl::TagValue(const std::string& tagName) const
 
 Tag BamRecordImpl::TagValue(const BamRecordTag tag) const
 {
-    return TagValue(internal::BamRecordTags::LabelFor(tag));
+    return TagValue(BamRecordTags::LabelFor(tag));
 }
 
 void BamRecordImpl::UpdateTagMap() const
@@ -622,8 +800,9 @@ void BamRecordImpl::UpdateTagMap() const
 
                     // unknown subTagType
                     default:
-                        throw std::runtime_error{"unsupported array-tag-type encountered: " +
-                                                 std::string{1, subTagType}};
+                        throw std::runtime_error{
+                            "[pbbam] BAM record ERROR: unsupported array-tag-type encountered: " +
+                            std::string{1, subTagType}};
                 }
 
                 uint32_t numElements = 0;
@@ -634,8 +813,9 @@ void BamRecordImpl::UpdateTagMap() const
 
             // unknown tagType
             default:
-                throw std::runtime_error{"unsupported tag-type encountered: " +
-                                         std::string{1, tagType}};
+                throw std::runtime_error{
+                    "[pbbam] BAM record ERROR: unsupported tag-type encountered: " +
+                    std::string{1, tagType}};
         }
     }
 }
