@@ -11,6 +11,7 @@
 #include <cassert>
 #include <cstddef>
 #include <cstdint>
+
 #include <sstream>
 #include <string>
 #include <unordered_map>
@@ -56,7 +57,8 @@ IndexList readLengthHelper(const std::vector<T>& start, const std::vector<T>& en
             default:
                 assert(false);
                 throw std::runtime_error{
-                    "PbiFilter: read length filter encountered unknown compare type: " +
+                    "[pbbam] PBI filter ERROR: read length filter encountered unknown compare "
+                    "type: " +
                     Compare::TypeToName(cmp)};
         }
 
@@ -65,32 +67,6 @@ IndexList readLengthHelper(const std::vector<T>& start, const std::vector<T>& en
     return result;
 }
 
-PbiFilter filterFromMovieName(const std::string& movieName, bool includeCcs)
-{
-    //
-    // All transcript-type reads (movieName == "transcript") have the same
-    // read group ID. Calculate once & and create filters from that ID.
-    //
-    if (movieName == "transcript") {
-        static const auto transcriptRgId = MakeReadGroupId("transcript", "TRANSCRIPT");
-        return PbiFilter{PbiReadGroupFilter{transcriptRgId}};
-    }
-
-    //
-    // For all other movie names, we can't determine read type up front, so we'll match
-    // on any rgIds from a candidate list.
-    //
-    auto filter = PbiFilter{PbiFilter::UNION};
-    filter.Add({PbiReadGroupFilter{MakeReadGroupId(movieName, "POLYMERASE")},
-                PbiReadGroupFilter{MakeReadGroupId(movieName, "HQREGION")},
-                PbiReadGroupFilter{MakeReadGroupId(movieName, "SUBREAD")},
-                PbiReadGroupFilter{MakeReadGroupId(movieName, "SCRAP")},
-                PbiReadGroupFilter{MakeReadGroupId(movieName, "UNKNOWN")}});
-    if (includeCcs) filter.Add(PbiReadGroupFilter{MakeReadGroupId(movieName, "CCS")});
-
-    return filter;
-}
-
 }  // namespace
 
 // PbiAlignedLengthFilter
@@ -128,17 +104,82 @@ bool PbiIdentityFilter::Accepts(const PbiRawData& idx, const size_t row) const
 // PbiMovieNameFilter
 
 PbiMovieNameFilter::PbiMovieNameFilter(const std::string& movieName, const Compare::Type cmp)
-    : compositeFilter_{filterFromMovieName(movieName, true)}  // include CCS
-    , cmp_{cmp}
+    : PbiMovieNameFilter{{1, movieName}, cmp}
 {
 }
 
 PbiMovieNameFilter::PbiMovieNameFilter(const std::vector<std::string>& movieNames,
                                        const Compare::Type cmp)
-    : compositeFilter_{PbiFilter::UNION}, cmp_{cmp}
+    : cmp_{cmp}
 {
-    for (const auto& movieName : movieNames)
-        compositeFilter_.Add(filterFromMovieName(movieName, true));  // include CCS
+    if (cmp_ == Compare::EQUAL)
+        cmp_ = Compare::CONTAINS;
+    else if (cmp_ == Compare::NOT_EQUAL)
+        cmp_ = Compare::NOT_CONTAINS;
+
+    if (cmp_ != Compare::CONTAINS && cmp_ != Compare::NOT_CONTAINS) {
+        throw std::runtime_error{
+            "[pbbam] PBI filter ERROR: unsupported compare type (" + Compare::TypeToName(cmp) +
+            ") for this property. "
+            "Movie name filter can only compare equality or presence in whitelist/blacklist."};
+    }
+
+    for (const auto& movieName : movieNames) {
+        candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "CCS")));
+        candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "TRANSCRIPT")));
+        candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "POLYMERASE")));
+        candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "HQREGION")));
+        candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "SUBREAD")));
+        candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "SCRAP")));
+        candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "UNKNOWN")));
+        candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "ZMW")));
+        movieNames_.insert(movieName);
+    }
+}
+
+bool PbiMovieNameFilter::Accepts(const PbiRawData& idx, const size_t row) const
+{
+    const auto accepted = [this](const PbiRawData& index, const size_t i) {
+
+        // straightforward lookup
+        const auto& rgId = index.BasicData().rgId_.at(i);
+        const auto foundAt = candidateRgIds_.find(rgId);
+        if (foundAt != candidateRgIds_.cend()) return true;
+
+        // if no barcode context available, record movie name fails
+        if (!index.HasBarcodeData()) return false;
+
+        // try barcoded RG IDs
+        const auto& barcodeData = index.BarcodeData();
+        const auto barcodes =
+            std::make_pair(barcodeData.bcForward_.at(i), barcodeData.bcReverse_.at(i));
+        for (const auto& movieName : movieNames_) {
+            const auto tryBarcodedType = [&](const std::string& readType) {
+                const int32_t barcodedId =
+                    ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, readType, barcodes));
+                if (barcodedId == rgId) {
+                    candidateRgIds_.insert(barcodedId);  // found combo, save for future lookup
+                    return true;
+                }
+                return false;
+            };
+
+            if (tryBarcodedType("CCS")) return true;
+            if (tryBarcodedType("TRANSCRIPT")) return true;
+            if (tryBarcodedType("SUBREAD")) return true;
+            if (tryBarcodedType("ZMW")) return true;
+            if (tryBarcodedType("POLYMERASE")) return true;
+            if (tryBarcodedType("HQREGION")) return true;
+            if (tryBarcodedType("SCRAP")) return true;
+            if (tryBarcodedType("UNKNOWN")) return true;
+        }
+
+        // not found at all
+        return false;
+    }(idx, row);
+
+    assert(cmp_ == Compare::CONTAINS || cmp_ == Compare::NOT_CONTAINS);
+    return (cmp_ == Compare::CONTAINS ? accepted : !accepted);
 }
 
 // PbiQueryLengthFilter
@@ -216,7 +257,8 @@ public:
         else if (cmp_ == Compare::NOT_EQUAL || cmp_ == Compare::NOT_CONTAINS)
             return !found;
         else
-            throw std::runtime_error{"PbiFilter: unsupported compare type on query name filter"};
+            throw std::runtime_error{
+                "[pbbam] PBI filter ERROR: unsupported compare type on query name filter"};
     }
 
     std::vector<int32_t> CandidateRgIds(const std::string& movieName, const RecordType type)
@@ -245,13 +287,13 @@ public:
         if (IsCcsOrTranscript(type)) {
             if (nameParts.size() != 2) {
                 const auto typeName = (type == RecordType::CCS) ? "CCS" : "transcript";
-                throw std::runtime_error{"PbiQueryNameFilter: requested QNAME (" + queryName +
+                throw std::runtime_error{"[pbbam] PBI filter ERROR: requested QNAME (" + queryName +
                                          ") is not valid for PacBio " + typeName +
                                          " reads. See spec for details."};
             }
         } else {
             if (nameParts.size() != 3) {
-                throw std::runtime_error{"PbiQueryNameFilter: requested QNAME (" + queryName +
+                throw std::runtime_error{"[pbbam] PBI filter ERROR: requested QNAME (" + queryName +
                                          ") is not a valid PacBio BAM QNAME. See spec for details"};
             }
         }
@@ -267,7 +309,7 @@ public:
         else {
             const auto queryIntervalParts = Split(nameParts.at(2), '_');
             if (queryIntervalParts.size() != 2) {
-                throw std::runtime_error{"PbiQueryNameFilter: requested QNAME (" + queryName +
+                throw std::runtime_error{"[pbbam] PBI filter ERROR: requested QNAME (" + queryName +
                                          ") is not a valid PacBio BAM QNAME. See spec for details"};
             }
             UpdateZmwQueryIntervals(zmwPtr.get(), zmw, std::stoi(queryIntervalParts.at(0)),
@@ -349,7 +391,7 @@ PbiReadGroupFilter::PbiReadGroupFilter(const std::vector<int32_t>& rgIds, const
 
     if (cmp_ != Compare::CONTAINS && cmp_ != Compare::NOT_CONTAINS) {
         throw std::runtime_error{
-            "PbiFilter: unsupported compare type (" + Compare::TypeToName(cmp) +
+            "[pbbam] PBI filter ERROR: unsupported compare type (" + Compare::TypeToName(cmp) +
             ") for this property. "
             "Read group filter can only compare equality or presence in whitelist/blacklist."};
     }
@@ -379,7 +421,7 @@ PbiReadGroupFilter::PbiReadGroupFilter(const std::vector<ReadGroupInfo>& readGro
 
     if (cmp_ != Compare::CONTAINS && cmp_ != Compare::NOT_CONTAINS) {
         throw std::runtime_error{
-            "PbiFilter: unsupported compare type (" + Compare::TypeToName(cmp) +
+            "[pbbam] PBI filter ERROR: unsupported compare type (" + Compare::TypeToName(cmp) +
             ") for this property. "
             "Read group filter can only compare equality or presence in whitelist/blacklist."};
     }
@@ -512,7 +554,7 @@ void PbiReferenceNameFilter::Validate() const
     }();
     if (!compareTypeOk) {
         throw std::runtime_error{
-            "PbiFilter: unsupported compare type (" + Compare::TypeToName(cmp_) +
+            "[pbbam] PBI filter ERROR: unsupported compare type (" + Compare::TypeToName(cmp_) +
             ") for this property. "
             "Reference name filter can only compare equality or presence in whitelist/blacklist."};
     }
