@@ -32,7 +32,7 @@ VirtualZmwBamRecord VirtualZmwCompositeReader::Next()
 
     // no reader active
     throw std::runtime_error{
-        "VirtualZmwCompositeReader: "
+        "[pbbam] stitched ZMW record reader ERROR: "
         "no readers active, make sure you use "
         "VirtualZmwCompositeReader::HasNext before "
         "requesting next record"};
@@ -48,7 +48,7 @@ std::vector<BamRecord> VirtualZmwCompositeReader::NextRaw()
 
     // no reader active
     throw std::runtime_error{
-        "VirtualZmwCompositeReader: "
+        "[pbbam] stitched ZMW record reader ERROR: "
         "no readers active, make sure you use "
         "VirtualZmwCompositeReader::HasNext before "
         "requesting next group of records"};
