@@ -8,6 +8,7 @@
 
 #include "VirtualZmwReader.h"
 
+#include <sstream>
 #include <stdexcept>
 
 #include "pbbam/ReadGroupInfo.h"
@@ -42,10 +43,13 @@ VirtualZmwReader::VirtualZmwReader(const std::string& primaryBamFilepath,
 
     // update stitched read group in header
     auto readGroups = stitchedHeader_->ReadGroups();
-    if (readGroups.empty())
-        throw std::runtime_error{
-            "VirtualZmwReader: no read groups in header of the primary BAM file: " +
-            primaryBamFilepath};
+    if (readGroups.empty()) {
+        std::ostringstream msg;
+        msg << "[pbbam] stitched ZMW record reader ERROR: no read groups in header of the primary "
+               "BAM:\n"
+            << "  file: " << primaryBamFilepath;
+        throw std::runtime_error{msg.str()};
+    }
     readGroups[0].ReadType("POLYMERASE");
     readGroups[0].Id(readGroups[0].MovieName(), "POLYMERASE");
     if (readGroups.size() > 1) {
