@@ -8,6 +8,8 @@
 #include <iosfwd>
 #include <memory>
 
+#include "pbbam/DataSetTypes.h"
+
 namespace PacBio {
 namespace BAM {
 
@@ -16,8 +18,9 @@ class DataSetBase;
 class XmlWriter
 {
 public:
-    static void ToStream(const DataSetBase& dataset, std::ostream& out);
-    static void ToStream(const std::unique_ptr<DataSetBase>& dataset, std::ostream& out);
+    static void ToStream(const DataSetBase& dataset, std::ostream& out, DataSetPathMode pathMode);
+    static void ToStream(const std::unique_ptr<DataSetBase>& dataset, std::ostream& out,
+                         DataSetPathMode pathMode);
 };
 
 }  // namespace BAM
