@@ -65,8 +65,8 @@ TEST(BamRecordMappingTest, BasicMap)
 
     const std::string seq_rev   = "GCTAACGGTT";
     const std::string quals_rev = "*?]?]?]?]?";
-    const std::string tagBases_rev = seq_rev;
-    const std::string tagQuals_rev = quals_rev;
+    const std::string& tagBases_rev = seq_rev;
+    const std::string& tagQuals_rev = quals_rev;
     const f_data frames_rev = { 20, 30, 10, 40, 40, 30, 20, 20, 10, 10 };
 
     const std::string s1_cigar = "10=";
@@ -343,8 +343,8 @@ TEST(BamRecordMappingTest, SoftClipMapping)
 
     const std::string seq_rev   = "TTTGCTAACGGTTAA";
     const std::string quals_rev = "+++*?]?]?]?]?--";
-    const std::string tagBases_rev = seq_rev;
-    const std::string tagQuals_rev = quals_rev;
+    const std::string& tagBases_rev = seq_rev;
+    const std::string& tagQuals_rev = quals_rev;
     const f_data frames_rev = { 10, 10, 10, 20, 30, 10, 40, 40, 30, 20, 20, 10, 10, 40, 40 };
 
     const std::string s1_cigar = "2S10=3S";
