@@ -125,68 +125,23 @@ TEST(DataSetIOTest, FromXmlFile)
 
 TEST(DataSetIOTest, ThrowsOnNonexistentFofnFile)
 {
-    bool checkedException = false;
-    try
-    {
-        auto ds = DataSet{"does/not/exist.fofn"};
-    }
-    catch(std::runtime_error& e)
-    {
-        const std::string msg = "DataSet: could not open FOFN for reading: does/not/exist.fofn";
-        EXPECT_EQ(msg, e.what()) ;
-        checkedException = true;
-    }
-    EXPECT_TRUE(checkedException);
+    EXPECT_THROW(DataSet("does/not/exist.fofn"), std::exception);
 }
 
 TEST(DataSetIOTest, ThrowsOnNonexistentXmlFile)
 {
-    bool checkedException = false;
-    try
-    {
-        auto ds = DataSet{"does/not/exist.xml"};
-    }
-    catch(std::runtime_error& e)
-    {
-        const std::string msg = "DataSet: could not open XML file for reading: does/not/exist.xml";
-        EXPECT_EQ(msg, e.what()) ;
-        checkedException = true;
-    }
-    EXPECT_TRUE(checkedException);
+    EXPECT_THROW(DataSet("does/not/exist.xml"), std::exception);
 }
 
 TEST(DataSetIOTest, ThrowsOnUnsupportedExtension)
 {
-    bool checkedException = false;
-    try
-    {
-        auto ds = DataSet{"bad/extension.foo"};
-    }
-    catch(std::runtime_error& e)
-    {
-        const std::string msg = "DataSet: unsupported extension on input file: bad/extension.foo";
-        EXPECT_EQ(msg, e.what()) ;
-        checkedException = true;
-    }
-    EXPECT_TRUE(checkedException);
+    EXPECT_THROW(DataSet("bad/extension.foo"), std::exception);
 }
 
 TEST(DataSetIOTest, ThrowsIfCannotOpenSaveFile)
 {
-    bool checkedException = false;
-    try
-    {
-        auto ds = DataSet{};
-        std::string fn = "fake_directory_that_should_not_exist/out.xml";
-        ds.Save(fn);
-    }
-    catch(std::runtime_error& e)
-    {
-        const std::string msg = "DataSet: could not open XML file for writing: fake_directory_that_should_not_exist/out.xml";
-        EXPECT_EQ(msg, e.what()) ;
-        checkedException = true;
-    }
-    EXPECT_TRUE(checkedException);
+    DataSet ds;
+    EXPECT_THROW(ds.Save("fake_directory_that_should_not_exist/out.xml"), std::exception);
 }
 
 TEST(DataSetIOTest, ToXml)
@@ -318,7 +273,7 @@ TEST(DataSetIOTest, ToXml)
         "\t\t\t<pbds:Filters>\n"
         "\t\t\t\t<pbds:Filter>\n"
         "\t\t\t\t\t<pbbase:Properties>\n"
-        "\t\t\t\t\t\t<pbbase:Property Name=\"rq\" Operator=\">\" Value=\"0.85\" />\n"
+        "\t\t\t\t\t\t<pbbase:Property Name=\"rq\" Operator=\"&gt;\" Value=\"0.85\" />\n"
         "\t\t\t\t\t</pbbase:Properties>\n"
         "\t\t\t\t</pbds:Filter>\n"
         "\t\t\t</pbds:Filters>\n"
@@ -1408,147 +1363,154 @@ static void TestTransformedXml()
 
 } // namespace DataSetIOTests
 
-TEST(DataSetIOTest, InspectMalformedXml)
-{
-    const std::string xmlFn = PbbamTestsConfig::Data_Dir + "/dataset/malformed.xml";
+//
+// NOTE(DB): 2020 Feb 14
+//           Removing this test, it was dirty hack to be permissive and not choke
+//           on an older malformed XML pathology. We have better validation &
+//           tool support now. This test is getting in the way of actual format
+//           bugfixes.
+//
+// TEST(DataSetIOTest, InspectMalformedXml)
+// {
+//     const std::string xmlFn = PbbamTestsConfig::Data_Dir + "/dataset/malformed.xml";
 
-    DataSet ds(xmlFn);
-    std::ostringstream s;
-    ds.SaveToStream(s);
+//     DataSet ds(xmlFn);
+//     std::ostringstream s;
+//     ds.SaveToStream(s);
 
-    const std::string expected{
-        "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n"
-        "<SubreadSet CreatedAt=\"2015-08-19T15:39:36.331\" Description=\"Merged dataset from 1 files using DatasetMerger 0.1.2\" "
-                    "MetaType=\"PacBio.DataSet.HdfSubreadSet\" Name=\"Subreads from runr000013_42267_150403\" "
-                    "Tags=\"pacbio.secondary.instrument=RS\" TimeStampedName=\"hdfsubreadset_2015-08-19T15:39:36.331-07:00\" "
-                    "UniqueId=\"b4741521-2a4c-42df-8a13-0a755ca9ed1e\" Version=\"0.5\" "
-                    "xmlns=\"http://pacificbiosciences.com/PacBioDatasets.xsd\" "
-                    "xmlns:ns0=\"http://pacificbiosciences.com/PacBioBaseDataModel.xsd\" "
-                    "xmlns:ns1=\"http://pacificbiosciences.com/PacBioSampleInfo.xsd\" "
-                    "xmlns:ns2=\"http://pacificbiosciences.com/PacBioCollectionMetadata.xsd\" "
-                    "xmlns:ns3=\"http://pacificbiosciences.com/PacBioReagentKit.xsd\" "
-                    "xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" "
-                    "xsi:schemaLocation=\"http://pacificbiosciences.com/PacBioDatasets.xsd\">\n"
-        "\t<ns0:ExternalResources>\n"
-        "\t\t<ns0:ExternalResource MetaType=\"SubreadFile.SubreadBamFile\" "
-                                  "ResourceId=\"file:///mnt/secondary-siv/jenkins/jenkins-bot01/workspace/Ubuntu1404_Mainline_SA3_Tiny_tests/software/smrtanalysis/siv/testkit-jobs/sa3_pipelines/mapping/tiny/job_output-ubuntu1404/tasks/pbsmrtpipe.tasks.h5_subreads_to_subread-0//mnt/secondary-siv/jenkins/jenkins-bot01/workspace/Ubuntu1404_Mainline_SA3_Tiny_tests/software/smrtanalysis/siv/testkit-jobs/sa3_pipelines/mapping/tiny/job_output-ubuntu1404/tasks/pbsmrtpipe.tasks.h5_subreads_to_subread-0/file.subreads.subreads.bam\" "
-                                  "TimeStampedName=\"SubreadFile.SubreadBamFile_00000000000000\" "
-                                  "UniqueId=\"251acf71-9eb0-489e-9dd1-cdbd11432753\" />\n"
-        "\t</ns0:ExternalResources>\n"
-        "\t<DataSetMetadata>\n"
-        "\t\t<TotalLength>50000000</TotalLength>\n"
-        "\t\t<NumRecords>150000</NumRecords>\n"
-        "\t\t<ns2:Collections>\n"
-        "\t\t\t<ns2:CollectionMetadata Context=\"m150404_101626_42267_c100807920800000001823174110291514_s1_p0\" "
-                                      "InstrumentId=\"1\" InstrumentName=\"42267\" MetaType=\"PacBio.Collection\" "
-                                      "TimeStampedName=\"m150404_101626_42267_c100807920800000001823174110291514_s1_p0\" "
-                                      "UniqueId=\"d66c8372-2b70-4dcf-b64f-9f8b5cc351fd\">\n"
-        "\t\t\t\t<ns2:InstCtrlVer>2.3.0.1.142990</ns2:InstCtrlVer>\n"
-        "\t\t\t\t<ns2:SigProcVer>NRT@172.31.128.10:8082, SwVer=2301.142990, HwVer=1.0</ns2:SigProcVer>\n"
-        "\t\t\t\t<ns2:RunDetails>\n"
-        "\t\t\t\t\t<ns2:RunId>r000013_42267_150403</ns2:RunId>\n"
-        "\t\t\t\t\t<ns2:Name>Inst42267-040315-SAT-100pM-2kb-P6C4</ns2:Name>\n"
-        "\t\t\t\t</ns2:RunDetails>\n"
-        "\t\t\t\t<ns2:WellSample Name=\"Inst42267-040315-SAT-100pM-2kb-P6C4\">\n"
-        "\t\t\t\t\t<ns2:PlateId>Inst42267-040315-SAT-100pM-2kb-P6C4</ns2:PlateId>\n"
-        "\t\t\t\t\t<ns2:WellName>Inst42267-040315-SAT-100pM-2kb-P6C4</ns2:WellName>\n"
-        "\t\t\t\t\t<ns2:Concentration>0.0</ns2:Concentration>\n"
-        "\t\t\t\t\t<ns2:SampleReuseEnabled>false</ns2:SampleReuseEnabled>\n"
-        "\t\t\t\t\t<ns2:StageHotstartEnabled>false</ns2:StageHotstartEnabled>\n"
-        "\t\t\t\t\t<ns2:SizeSelectionEnabled>false</ns2:SizeSelectionEnabled>\n"
-        "\t\t\t\t\t<ns2:UseCount>1</ns2:UseCount>\n"
-        "\t\t\t\t\t<ns1:BioSamplePointers>\n"
-        "\t\t\t\t\t\t<ns1:BioSamplePointer>251acf71-9eb0-489e-9dd1-cdbd11432752</ns1:BioSamplePointer>\n"
-        "\t\t\t\t\t</ns1:BioSamplePointers>\n"
-        "\t\t\t\t</ns2:WellSample>\n"
-        "\t\t\t\t<ns2:Automation>\n"
-        "\t\t\t\t\t<ns0:AutomationParameters>\n"
-        "\t\t\t\t\t\t<ns0:AutomationParameter />\n"
-        "\t\t\t\t\t</ns0:AutomationParameters>\n"
-        "\t\t\t\t</ns2:Automation>\n"
-        "\t\t\t\t<ns2:CollectionNumber>7</ns2:CollectionNumber>\n"
-        "\t\t\t\t<ns2:CellIndex>4</ns2:CellIndex>\n"
-        "\t\t\t\t<ns2:CellPac Barcode=\"10080792080000000182317411029151\" />\n"
-        "\t\t\t\t<ns2:Primary>\n"
-        "\t\t\t\t\t<ns2:AutomationName>BasecallerV1</ns2:AutomationName>\n"
-        "\t\t\t\t\t<ns2:ConfigFileName>2-3-0_P6-C4.xml</ns2:ConfigFileName>\n"
-        "\t\t\t\t\t<ns2:SequencingCondition />\n"
-        "\t\t\t\t\t<ns2:OutputOptions>\n"
-        "\t\t\t\t\t\t<ns2:ResultsFolder>Analysis_Results</ns2:ResultsFolder>\n"
-        "\t\t\t\t\t\t<ns2:CollectionPathUri>rsy://mp-rsync/vol55//RS_DATA_STAGING/42267/Inst42267-040315-SAT-100pM-2kb-P6C4_13/A04_7/</ns2:CollectionPathUri>\n"
-        "\t\t\t\t\t\t<ns2:CopyFiles>\n"
-        "\t\t\t\t\t\t\t<ns2:CollectionFileCopy>Fasta</ns2:CollectionFileCopy>\n"
-        "\t\t\t\t\t\t</ns2:CopyFiles>\n"
-        "\t\t\t\t\t\t<ns2:Readout>Bases</ns2:Readout>\n"
-        "\t\t\t\t\t\t<ns2:MetricsVerbosity>Minimal</ns2:MetricsVerbosity>\n"
-        "\t\t\t\t\t</ns2:OutputOptions>\n"
-        "\t\t\t\t</ns2:Primary>\n"
-        "\t\t\t</ns2:CollectionMetadata>\n"
-        "\t\t</ns2:Collections>\n"
-        "\t\t<ns1:BioSamples>\n"
-        "\t\t\t<ns1:BioSample Description=\"Inst42267-SAT-100pM-2kbLambda-P6C4-Std120_CPS_040315\" "
-                            "MetaType=\"PacBio.Sample\" Name=\"Inst42267-040315-SAT-100pM-2kb-P6C4\" "
-                            "TimeStampedName=\"biosample_2015-08-19T15:39:36.331-07:00\" UniqueId=\"251acf71-9eb0-489e-9dd1-cdbd11432752\" />\n"
-        "\t\t</ns1:BioSamples>\n"
-        "\t</DataSetMetadata>\n"
-        "</SubreadSet>\n"};
+//     const std::string expected{
+//         "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n"
+//         "<SubreadSet CreatedAt=\"2015-08-19T15:39:36.331\" Description=\"Merged dataset from 1 files using DatasetMerger 0.1.2\" "
+//                     "MetaType=\"PacBio.DataSet.HdfSubreadSet\" Name=\"Subreads from runr000013_42267_150403\" "
+//                     "Tags=\"pacbio.secondary.instrument=RS\" TimeStampedName=\"hdfsubreadset_2015-08-19T15:39:36.331-07:00\" "
+//                     "UniqueId=\"b4741521-2a4c-42df-8a13-0a755ca9ed1e\" Version=\"0.5\" "
+//                     "xmlns=\"http://pacificbiosciences.com/PacBioDatasets.xsd\" "
+//                     "xmlns:ns0=\"http://pacificbiosciences.com/PacBioBaseDataModel.xsd\" "
+//                     "xmlns:ns1=\"http://pacificbiosciences.com/PacBioSampleInfo.xsd\" "
+//                     "xmlns:ns2=\"http://pacificbiosciences.com/PacBioCollectionMetadata.xsd\" "
+//                     "xmlns:ns3=\"http://pacificbiosciences.com/PacBioReagentKit.xsd\" "
+//                     "xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" "
+//                     "xsi:schemaLocation=\"http://pacificbiosciences.com/PacBioDatasets.xsd\">\n"
+//         "\t<ns0:ExternalResources>\n"
+//         "\t\t<ns0:ExternalResource MetaType=\"SubreadFile.SubreadBamFile\" "
+//                                   "ResourceId=\"file:///mnt/secondary-siv/jenkins/jenkins-bot01/workspace/Ubuntu1404_Mainline_SA3_Tiny_tests/software/smrtanalysis/siv/testkit-jobs/sa3_pipelines/mapping/tiny/job_output-ubuntu1404/tasks/pbsmrtpipe.tasks.h5_subreads_to_subread-0//mnt/secondary-siv/jenkins/jenkins-bot01/workspace/Ubuntu1404_Mainline_SA3_Tiny_tests/software/smrtanalysis/siv/testkit-jobs/sa3_pipelines/mapping/tiny/job_output-ubuntu1404/tasks/pbsmrtpipe.tasks.h5_subreads_to_subread-0/file.subreads.subreads.bam\" "
+//                                   "TimeStampedName=\"SubreadFile.SubreadBamFile_00000000000000\" "
+//                                   "UniqueId=\"251acf71-9eb0-489e-9dd1-cdbd11432753\" />\n"
+//         "\t</ns0:ExternalResources>\n"
+//         "\t<DataSetMetadata>\n"
+//         "\t\t<TotalLength>50000000</TotalLength>\n"
+//         "\t\t<NumRecords>150000</NumRecords>\n"
+//         "\t\t<ns2:Collections>\n"
+//         "\t\t\t<ns2:CollectionMetadata Context=\"m150404_101626_42267_c100807920800000001823174110291514_s1_p0\" "
+//                                       "InstrumentId=\"1\" InstrumentName=\"42267\" MetaType=\"PacBio.Collection\" "
+//                                       "TimeStampedName=\"m150404_101626_42267_c100807920800000001823174110291514_s1_p0\" "
+//                                       "UniqueId=\"d66c8372-2b70-4dcf-b64f-9f8b5cc351fd\">\n"
+//         "\t\t\t\t<ns2:InstCtrlVer>2.3.0.1.142990</ns2:InstCtrlVer>\n"
+//         "\t\t\t\t<ns2:SigProcVer>NRT@172.31.128.10:8082, SwVer=2301.142990, HwVer=1.0</ns2:SigProcVer>\n"
+//         "\t\t\t\t<ns2:RunDetails>\n"
+//         "\t\t\t\t\t<ns2:RunId>r000013_42267_150403</ns2:RunId>\n"
+//         "\t\t\t\t\t<ns2:Name>Inst42267-040315-SAT-100pM-2kb-P6C4</ns2:Name>\n"
+//         "\t\t\t\t</ns2:RunDetails>\n"
+//         "\t\t\t\t<ns2:WellSample Name=\"Inst42267-040315-SAT-100pM-2kb-P6C4\">\n"
+//         "\t\t\t\t\t<ns2:PlateId>Inst42267-040315-SAT-100pM-2kb-P6C4</ns2:PlateId>\n"
+//         "\t\t\t\t\t<ns2:WellName>Inst42267-040315-SAT-100pM-2kb-P6C4</ns2:WellName>\n"
+//         "\t\t\t\t\t<ns2:Concentration>0.0</ns2:Concentration>\n"
+//         "\t\t\t\t\t<ns2:SampleReuseEnabled>false</ns2:SampleReuseEnabled>\n"
+//         "\t\t\t\t\t<ns2:StageHotstartEnabled>false</ns2:StageHotstartEnabled>\n"
+//         "\t\t\t\t\t<ns2:SizeSelectionEnabled>false</ns2:SizeSelectionEnabled>\n"
+//         "\t\t\t\t\t<ns2:UseCount>1</ns2:UseCount>\n"
+//         "\t\t\t\t\t<ns1:BioSamplePointers>\n"
+//         "\t\t\t\t\t\t<ns1:BioSamplePointer>251acf71-9eb0-489e-9dd1-cdbd11432752</ns1:BioSamplePointer>\n"
+//         "\t\t\t\t\t</ns1:BioSamplePointers>\n"
+//         "\t\t\t\t</ns2:WellSample>\n"
+//         "\t\t\t\t<ns2:Automation>\n"
+//         "\t\t\t\t\t<ns0:AutomationParameters>\n"
+//         "\t\t\t\t\t\t<ns0:AutomationParameter />\n"
+//         "\t\t\t\t\t</ns0:AutomationParameters>\n"
+//         "\t\t\t\t</ns2:Automation>\n"
+//         "\t\t\t\t<ns2:CollectionNumber>7</ns2:CollectionNumber>\n"
+//         "\t\t\t\t<ns2:CellIndex>4</ns2:CellIndex>\n"
+//         "\t\t\t\t<ns2:CellPac Barcode=\"10080792080000000182317411029151\" />\n"
+//         "\t\t\t\t<ns2:Primary>\n"
+//         "\t\t\t\t\t<ns2:AutomationName>BasecallerV1</ns2:AutomationName>\n"
+//         "\t\t\t\t\t<ns2:ConfigFileName>2-3-0_P6-C4.xml</ns2:ConfigFileName>\n"
+//         "\t\t\t\t\t<ns2:SequencingCondition />\n"
+//         "\t\t\t\t\t<ns2:OutputOptions>\n"
+//         "\t\t\t\t\t\t<ns2:ResultsFolder>Analysis_Results</ns2:ResultsFolder>\n"
+//         "\t\t\t\t\t\t<ns2:CollectionPathUri>rsy://mp-rsync/vol55//RS_DATA_STAGING/42267/Inst42267-040315-SAT-100pM-2kb-P6C4_13/A04_7/</ns2:CollectionPathUri>\n"
+//         "\t\t\t\t\t\t<ns2:CopyFiles>\n"
+//         "\t\t\t\t\t\t\t<ns2:CollectionFileCopy>Fasta</ns2:CollectionFileCopy>\n"
+//         "\t\t\t\t\t\t</ns2:CopyFiles>\n"
+//         "\t\t\t\t\t\t<ns2:Readout>Bases</ns2:Readout>\n"
+//         "\t\t\t\t\t\t<ns2:MetricsVerbosity>Minimal</ns2:MetricsVerbosity>\n"
+//         "\t\t\t\t\t</ns2:OutputOptions>\n"
+//         "\t\t\t\t</ns2:Primary>\n"
+//         "\t\t\t</ns2:CollectionMetadata>\n"
+//         "\t\t</ns2:Collections>\n"
+//         "\t\t<ns1:BioSamples>\n"
+//         "\t\t\t<ns1:BioSample Description=\"Inst42267-SAT-100pM-2kbLambda-P6C4-Std120_CPS_040315\" "
+//                             "MetaType=\"PacBio.Sample\" Name=\"Inst42267-040315-SAT-100pM-2kb-P6C4\" "
+//                             "TimeStampedName=\"biosample_2015-08-19T15:39:36.331-07:00\" UniqueId=\"251acf71-9eb0-489e-9dd1-cdbd11432752\" />\n"
+//         "\t\t</ns1:BioSamples>\n"
+//         "\t</DataSetMetadata>\n"
+//         "</SubreadSet>\n"};
 
-    EXPECT_EQ(expected, s.str());
-}
+//     EXPECT_EQ(expected, s.str());
+// }
 
-TEST(DataSetIOTest, RelativePathCarriedThroughOk_FromString)
-{
-    const std::string inputXml{
-        "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n"
-        "<pbds:AlignmentSet "
-            "CreatedAt=\"2015-01-27T09:00:01\" "
-            "MetaType=\"PacBio.DataSet.AlignmentSet\" "
-            "Name=\"DataSet_AlignmentSet\" "
-            "Tags=\"barcode moreTags mapping mytags\" "
-            "TimeStampedName=\"biosample_2015-08-19T15:39:36.331-07:00\" "
-            "UniqueId=\"b095d0a3-94b8-4918-b3af-a3f81bbe519c\" "
-            "Version=\"2.3.0\" "
-            "xmlns=\"http://pacificbiosciences.com/PacBioDataModel.xsd\" "
-            "xmlns:pbbase=\"http://pacificbiosciences.com/PacBioBaseDataModel.xsd\" "
-            "xmlns:pbds=\"http://pacificbiosciences.com/PacBioDatasets.xsd\" "
-            "xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" "
-            "xsi:schemaLocation=\"http://pacificbiosciences.com/PacBioDataModel.xsd\">\n"
-        "\t<pbbase:ExternalResources>\n"
-        "\t\t<pbbase:ExternalResource "
-                "Description=\"Points to an example Alignments BAM file.\" "
-                "MetaType=\"AlignmentFile.AlignmentBamFile\" "
-                "Name=\"Third Alignments BAM\" "
-                "ResourceId=\"../path/to/resource1.bam\" "
-                "Tags=\"Example\">\n"
-        "\t\t\t<pbbase:FileIndices>\n"
-        "\t\t\t\t<pbbase:FileIndex "
-                    "MetaType=\"PacBio.Index.PacBioIndex\" "
-                    "ResourceId=\"../path/to/resource1.bam.pbi\" />\n"
-        "\t\t\t</pbbase:FileIndices>\n"
-        "\t\t</pbbase:ExternalResource>\n"
-        "\t\t<pbbase:ExternalResource "
-                "Description=\"Points to another example Alignments BAM file, by relative path.\" "
-                "MetaType=\"AlignmentFile.AlignmentBamFile\" "
-                "Name=\"Fourth Alignments BAM\" "
-                "ResourceId=\"../path/to/resource2.bam\" "
-                "Tags=\"Example\">\n"
-        "\t\t\t<pbbase:FileIndices>\n"
-        "\t\t\t\t<pbbase:FileIndex "
-                    "MetaType=\"PacBio.Index.PacBioIndex\" "
-                    "ResourceId=\"../path/to/resource2.bam.pbi\" />\n"
-        "\t\t\t</pbbase:FileIndices>\n"
-        "\t\t</pbbase:ExternalResource>\n"
-        "\t</pbbase:ExternalResources>\n"
-        "</pbds:AlignmentSet>\n"};
+// TEST(DataSetIOTest, RelativePathCarriedThroughOk_FromString)
+// {
+//     const std::string inputXml{
+//         "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n"
+//         "<pbds:AlignmentSet "
+//             "CreatedAt=\"2015-01-27T09:00:01\" "
+//             "MetaType=\"PacBio.DataSet.AlignmentSet\" "
+//             "Name=\"DataSet_AlignmentSet\" "
+//             "Tags=\"barcode moreTags mapping mytags\" "
+//             "TimeStampedName=\"biosample_2015-08-19T15:39:36.331-07:00\" "
+//             "UniqueId=\"b095d0a3-94b8-4918-b3af-a3f81bbe519c\" "
+//             "Version=\"2.3.0\" "
+//             "xmlns=\"http://pacificbiosciences.com/PacBioDataModel.xsd\" "
+//             "xmlns:pbbase=\"http://pacificbiosciences.com/PacBioBaseDataModel.xsd\" "
+//             "xmlns:pbds=\"http://pacificbiosciences.com/PacBioDatasets.xsd\" "
+//             "xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" "
+//             "xsi:schemaLocation=\"http://pacificbiosciences.com/PacBioDataModel.xsd\">\n"
+//         "\t<pbbase:ExternalResources>\n"
+//         "\t\t<pbbase:ExternalResource "
+//                 "Description=\"Points to an example Alignments BAM file.\" "
+//                 "MetaType=\"AlignmentFile.AlignmentBamFile\" "
+//                 "Name=\"Third Alignments BAM\" "
+//                 "ResourceId=\"../path/to/resource1.bam\" "
+//                 "Tags=\"Example\">\n"
+//         "\t\t\t<pbbase:FileIndices>\n"
+//         "\t\t\t\t<pbbase:FileIndex "
+//                     "MetaType=\"PacBio.Index.PacBioIndex\" "
+//                     "ResourceId=\"../path/to/resource1.bam.pbi\" />\n"
+//         "\t\t\t</pbbase:FileIndices>\n"
+//         "\t\t</pbbase:ExternalResource>\n"
+//         "\t\t<pbbase:ExternalResource "
+//                 "Description=\"Points to another example Alignments BAM file, by relative path.\" "
+//                 "MetaType=\"AlignmentFile.AlignmentBamFile\" "
+//                 "Name=\"Fourth Alignments BAM\" "
+//                 "ResourceId=\"../path/to/resource2.bam\" "
+//                 "Tags=\"Example\">\n"
+//         "\t\t\t<pbbase:FileIndices>\n"
+//         "\t\t\t\t<pbbase:FileIndex "
+//                     "MetaType=\"PacBio.Index.PacBioIndex\" "
+//                     "ResourceId=\"../path/to/resource2.bam.pbi\" />\n"
+//         "\t\t\t</pbbase:FileIndices>\n"
+//         "\t\t</pbbase:ExternalResource>\n"
+//         "\t</pbbase:ExternalResources>\n"
+//         "</pbds:AlignmentSet>\n"};
 
-    auto dataset = DataSet::FromXml(inputXml);
+//     auto dataset = DataSet::FromXml(inputXml);
 
-    std::ostringstream stream;
-    dataset.SaveToStream(stream);
-    auto outputXml = stream.str();
+//     std::ostringstream stream;
+//     dataset.SaveToStream(stream);
+//     auto outputXml = stream.str();
 
-    EXPECT_EQ(inputXml, outputXml);
-}
+//     EXPECT_EQ(inputXml, outputXml);
+// }
 
 TEST(DataSetIOTest, RelativePathCarriedThroughOk_FromFile)
 {
@@ -1751,4 +1713,49 @@ TEST(DataSetIOTest, AbsolutePathsForGenericAndDerivedDatasets)
     EXPECT_NE(referenceDatasetXml.find(expectedReferenceFn), std::string::npos);
 }
 
+TEST(DataSetIOTest, AmpersandsAreEscaped)
+{
+    SubreadSet ds;
+    internal::DataSetElement e{"Description", XsdType::COLLECTION_METADATA};
+    e.Text("Transfer location for R&D");
+    ds.AddChild(e);
+
+    std::ostringstream out;
+    ds.SaveToStream(out);
+    EXPECT_TRUE(out.str().find("R&amp;D") != std::string::npos);
+}
+
+TEST(DataSetIOTest, CanWriteRelativePathsInDoNovoDataset)
+{
+    const std::string file1{"file1.bam"};
+    const std::string file2{"subdir/file2.bam"};
+
+    const std::string relativeResource1{"ResourceId=\"file1.bam\""};
+    const std::string relativeResource2{"ResourceId=\"subdir/file2.bam\""};
+
+    DataSet dataset;
+    dataset.ExternalResources().Add(ExternalResource{"PacBio.SubreadFile.SubreadBamFile", file1});
+    dataset.ExternalResources().Add(ExternalResource{"PacBio.SubreadFile.SubreadBamFile", file2});
+
+    std::ostringstream out;
+    dataset.SaveToStream(out);
+
+    // contains the expected files, but has appended an absolute path
+    const std::string resolvedXml = out.str();
+    EXPECT_NE(std::string::npos, resolvedXml.find(file1));
+    EXPECT_NE(std::string::npos, resolvedXml.find(file2));
+    EXPECT_EQ(std::string::npos, resolvedXml.find(relativeResource1));
+    EXPECT_EQ(std::string::npos, resolvedXml.find(relativeResource2));
+
+    out.str("");
+    dataset.SaveToStream(out, DataSetPathMode::ALLOW_RELATIVE);
+
+    // contains just the verbatim, relative file path
+    const std::string unresolvedXml{out.str()};
+    EXPECT_NE(std::string::npos, unresolvedXml.find(file1));
+    EXPECT_NE(std::string::npos, unresolvedXml.find(file2));
+    EXPECT_NE(std::string::npos, unresolvedXml.find(relativeResource1));
+    EXPECT_NE(std::string::npos, unresolvedXml.find(relativeResource2));
+}
+
 // clang-format on
