@@ -1,39 +1,23 @@
 // Author: Derek Barnett
 
-#include <cstddef>
+#include <iterator>
 
 #include <gtest/gtest.h>
 
-#include "PbbamTestData.h"
-
-#include <pbbam/EntireFileQuery.h>
-#include <pbbam/FastaReader.h>
-#include <pbbam/FastaSequence.h>
 #include <pbbam/FastaSequenceQuery.h>
-#include <pbbam/FastaWriter.h>
-#include <pbbam/Unused.h>
-#include <boost/algorithm/string.hpp>
 
-#include "FastxTests.h"
+#include "PbbamTestData.h"
 
 using namespace PacBio;
 using namespace PacBio::BAM;
 
-namespace FastaSequenceQueryTests {
-}  // namespace FastaSequenceQueryTests
-
 TEST(FastaSequenceQueryTest, can_read_from_fasta_file)
 {
     const std::string fn = PbbamTestsConfig::Data_Dir + "/lambdaNEB.fa";
 
     {
-        size_t count = 0;
         FastaSequenceQuery query{fn};
-        for (const auto& seq : query) {
-            UNUSED(seq);
-            ++count;
-        }
-        EXPECT_EQ(1, count);
+        EXPECT_EQ(1, std::distance(query.begin(), query.end()));
     }
 
     {
@@ -49,13 +33,8 @@ TEST(FastaSequenceQueryTest, can_read_from_dataset)
     const std::string fn = PbbamTestsConfig::Data_Dir + "/referenceset.xml";
 
     {
-        size_t count = 0;
         FastaSequenceQuery query{fn};
-        for (const auto& seq : query) {
-            UNUSED(seq);
-            ++count;
-        }
-        EXPECT_EQ(5, count);  // 1 from lambda, 4 from chimera
+        EXPECT_EQ(5, std::distance(query.begin(), query.end()));  // 1 from lambda, 4 from chimera
     }
     {
         FastaSequenceQuery query{fn};
