@@ -4,18 +4,19 @@
 #include <chrono>
 #include <cstdio>
 #include <cstdlib>
+
 #include <iostream>
 #include <string>
+#include <tuple>
 #include <vector>
 
 #include <gtest/gtest.h>
 #include <boost/algorithm/string.hpp>
 
-#include "PbbamTestData.h"
-
 #include <pbbam/../../src/FileUtils.h>
 #include <pbbam/../../src/TimeUtils.h>
-#include <pbbam/Unused.h>
+
+#include "PbbamTestData.h"
 
 using namespace PacBio;
 using namespace PacBio::BAM;
@@ -25,7 +26,7 @@ TEST(FileUtilsTest, ExistsOk)
     EXPECT_FALSE(FileUtils::Exists("does_not_exist.txt"));
 
     const std::string tmp = PbbamTestsConfig::GeneratedData_Dir + "/pbbam_exists_check.tmp";
-    const std::string cmd = std::string("touch ") + tmp;
+    const std::string cmd = "touch " + tmp;
     ASSERT_EQ(0, system(cmd.c_str()));
     EXPECT_TRUE(FileUtils::Exists(tmp));
 }
@@ -41,10 +42,10 @@ TEST(FileUtilsTest, LastModifiedOk)
     const auto thenSeconds = std::chrono::duration_cast<std::chrono::seconds>(thenDuration).count();
 
     const std::string tmp = PbbamTestsConfig::GeneratedData_Dir + "/pbbam_lastmod_check.tmp";
-    const std::string rmCmd = std::string("rm ") + tmp;
-    const std::string touchCmd = std::string("touch  ") + tmp;
+    const std::string rmCmd = "rm " + tmp;
+    const std::string touchCmd = "touch  " + tmp;
     const auto ret = system(rmCmd.c_str());
-    UNUSED(ret);
+    std::ignore = ret;
     ASSERT_EQ(0, system(touchCmd.c_str()));
 
     const auto stamp = FileUtils::LastModified(tmp);
@@ -53,7 +54,6 @@ TEST(FileUtilsTest, LastModifiedOk)
         std::chrono::duration_cast<std::chrono::seconds>(stampDuration).count();
 
     const int skew = 3600;  // allow 1 hour of clock-skew
-
     EXPECT_LE(thenSeconds, stampSeconds + skew);
 }
 
@@ -113,7 +113,7 @@ TEST(FileUtilsTest, ResolvedFilePathOk)
 TEST(FileUtilsTest, SizeOk)
 {
     const std::string tmp = PbbamTestsConfig::GeneratedData_Dir + "/pbbam_empty_file.tmp";
-    const std::string cmd = std::string("touch ") + tmp;
+    const std::string cmd = "touch " + tmp;
     ASSERT_EQ(0, system(cmd.c_str()));
     EXPECT_EQ(0, FileUtils::Size(tmp));
 
@@ -131,21 +131,21 @@ TEST(FileUtilsTest, SizeOk)
 //
 namespace test_windows {
 
-static std::string removeFileUriScheme(const std::string& uri)
+std::string removeFileUriScheme(const std::string& uri)
 {
     assert(!uri.empty());
 
-    auto schemeLess = uri;
-    const auto fileScheme = std::string{"file://"};
+    std::string schemeLess{uri};
+    const std::string fileScheme = "file://";
     const auto schemeFound = schemeLess.find(fileScheme);
     if (schemeFound != std::string::npos) {
-        if (schemeFound != 0) throw std::runtime_error("Malformed URI: scheme not at beginning");
+        if (schemeFound != 0) throw std::runtime_error{"Malformed URI: scheme not at beginning"};
         schemeLess = schemeLess.substr(fileScheme.size());
     }
     return schemeLess;
 }
 
-static std::string removeDiskName(const std::string& filePath)
+std::string removeDiskName(const std::string& filePath)
 {
     if (filePath.size() >= 2) {
         const char firstChar = filePath.at(0);
@@ -154,9 +154,9 @@ static std::string removeDiskName(const std::string& filePath)
     return filePath;
 }
 
-static const char native_pathSeparator = '\\';
+const char native_pathSeparator = '\\';
 
-static bool native_pathIsAbsolute(const std::string& filePath)
+bool native_pathIsAbsolute(const std::string& filePath)
 {
     assert(!filePath.empty());
 
@@ -169,22 +169,25 @@ static bool native_pathIsAbsolute(const std::string& filePath)
     // if starts with drive name and colon ("C:\foo\bar.txt")
     if (filePath.size() >= 2) {
         const char firstChar = filePath.at(0);
-        if ((isalpha(firstChar) != 0) && (filePath.at(1) == ':'))
+        if ((isalpha(firstChar) != 0) && (filePath.at(1) == ':')) {
             return native_pathIsAbsolute(removeDiskName(filePath));
+        }
     }
 
     // otherwise, likely relative
     return false;
 }
 
-static std::string native_resolvedFilePath(const std::string& filePath, const std::string& from)
+std::string native_resolvedFilePath(const std::string& filePath, const std::string& from)
 {
     // strip file:// scheme if present
     auto schemeLess = removeFileUriScheme(filePath);
 
     // if empty or already absolute path, just return it
     // upfront empty check simplifies further parsing logic
-    if (schemeLess.empty() || native_pathIsAbsolute(schemeLess)) return schemeLess;
+    if (schemeLess.empty() || native_pathIsAbsolute(schemeLess)) {
+        return schemeLess;
+    }
 
     // else make relative from the provided 'from' directory
     //
@@ -211,19 +214,19 @@ TEST(FileUtilsTest, WindowsPathsOk)
     {  // remove disk name
 
         // "C:\tmp.txt"
-        std::string f1 = "C:\\tmp.txt";
-        EXPECT_EQ(std::string("\\tmp.txt"), test_windows::removeDiskName(f1));
+        const std::string f1{"C:\\tmp.txt"};
+        EXPECT_EQ("\\tmp.txt", test_windows::removeDiskName(f1));
 
         // "C:tmp.txt"
-        std::string f2 = "C:tmp.txt";
-        EXPECT_EQ(std::string("tmp.txt"), test_windows::removeDiskName(f2));
+        const std::string f2{"C:tmp.txt"};
+        EXPECT_EQ("tmp.txt", test_windows::removeDiskName(f2));
 
         // "\tmp.txt"
-        std::string f3 = "\\tmp.txt";
+        const std::string f3{"\\tmp.txt"};
         EXPECT_EQ(f3, test_windows::removeDiskName(f3));
 
         // "tmp.txt"
-        std::string f4 = "tmp.txt";
+        const std::string f4{"tmp.txt"};
         EXPECT_EQ(f4, test_windows::removeDiskName(f4));
     }
 
@@ -247,36 +250,36 @@ TEST(FileUtilsTest, WindowsPathsOk)
 
     {  // resolve file path
 
-        const std::string myRootDir = "C:\\path\\to\\myRootDir";
+        const std::string myRootDir{R"(C:\path\to\myRootDir)"};
 
         // "\\server\path\to\tmp.txt"
-        const std::string fn1 = "\\\\server\\path\\to\tmp.txt";
-        const std::string fn1_expected = fn1;
+        const std::string fn1{R"(\\server\path\to\tmp.txt)"};
+        const std::string& fn1_expected{fn1};
         EXPECT_EQ(fn1_expected, test_windows::native_resolvedFilePath(fn1, myRootDir));
 
         // "..\tmp.txt"
-        const std::string fn2 = "..\\tmp.txt";
-        const std::string fn2_expected = "C:\\path\\to\\myRootDir\\..\\tmp.txt";
+        const std::string fn2{R"(..\tmp.txt)"};
+        const std::string fn2_expected{R"(C:\path\to\myRootDir\..\tmp.txt)"};
         EXPECT_EQ(fn2_expected, test_windows::native_resolvedFilePath(fn2, myRootDir));
 
         // ".\tmp.txt"
-        const std::string fn3 = ".\\tmp.txt";
-        const std::string fn3_expected = "C:\\path\\to\\myRootDir\\tmp.txt";
+        const std::string fn3{R"(.\tmp.txt)"};
+        const std::string fn3_expected{R"(C:\path\to\myRootDir\tmp.txt)"};
         EXPECT_EQ(fn3_expected, test_windows::native_resolvedFilePath(fn3, myRootDir));
 
         // "C:\path\to\tmp.txt"
-        const std::string fn4 = "C:\\path\\to\\tmp.txt";
-        const std::string fn4_expected = fn4;
+        const std::string fn4{R"(C:\path\to\tmp.txt)"};
+        const std::string& fn4_expected{fn4};
         EXPECT_EQ(fn4_expected, test_windows::native_resolvedFilePath(fn4, myRootDir));
 
         // "C:..\path\to\tmp.txt"
-        const std::string fn5 = "C:..\\path\\to\\tmp.txt";
-        const std::string fn5_expected = "C:\\path\\to\\myRootDir\\..\\path\\to\\tmp.txt";
+        const std::string fn5{R"(C:..\path\to\tmp.txt)"};
+        const std::string fn5_expected{R"(C:\path\to\myRootDir\..\path\to\tmp.txt)"};
         EXPECT_EQ(fn5_expected, test_windows::native_resolvedFilePath(fn5, myRootDir));
 
         // "C:tmp.txt"
-        const std::string fn6 = "C:tmp.txt";
-        const std::string fn6_expected = "C:\\path\\to\\myRootDir\\tmp.txt";
+        const std::string fn6{"C:tmp.txt"};
+        const std::string fn6_expected{R"(C:\path\to\myRootDir\tmp.txt)"};
         EXPECT_EQ(fn6_expected, test_windows::native_resolvedFilePath(fn6, myRootDir));
         EXPECT_EQ(fn3_expected,
                   test_windows::native_resolvedFilePath(
