@@ -1,9 +1,11 @@
 // Author: Derek Barnett
 
+#include <algorithm>
 #include <string>
 #include <vector>
 
 #include <gtest/gtest.h>
+
 #include <pbbam/vcf/VcfFile.h>
 #include <pbbam/vcf/VcfQuery.h>
 
@@ -15,14 +17,13 @@ using VcfVariant = PacBio::VCF::VcfVariant;
 
 namespace VcfQueryTests {
 
-static const std::vector<std::string> ExpectedIds{
+const std::vector<std::string> ExpectedIds{
     "pbsv.INS.1",  "pbsv.DEL.2",  "pbsv.INS.3",  "pbsv.INS.4",  "pbsv.DEL.5",  "pbsv.DEL.6",
     "pbsv.DEL.7",  "pbsv.INS.8",  "pbsv.INS.9",  "pbsv.INS.10", "pbsv.INS.11", "pbsv.INS.12",
     "pbsv.INS.13", "pbsv.INS.14", "pbsv.INS.15", "pbsv.INS.16", "pbsv.INS.17", "pbsv.INS.18",
     "pbsv.INS.19", "pbsv.DEL.20", "pbsv.INS.21"};
 
-static const std::string VcfFn{PacBio::BAM::PbbamTestsConfig::Data_Dir +
-                               "/vcf/structural_variants.vcf"};
+const std::string VcfFn{PacBio::BAM::PbbamTestsConfig::Data_Dir + "/vcf/structural_variants.vcf"};
 
 }  // namespace VcfQueryTests
 
