@@ -12,34 +12,24 @@
 using VcfFile = PacBio::VCF::VcfFile;
 using VcfQuery = PacBio::VCF::VcfQuery;
 
-// clang-format off
-
 namespace VcfSortTests {
 
-static const std::string inputFn = PacBio::BAM::PbbamTestsConfig::Data_Dir +
-        "/vcf/unsorted.vcf";
-static const std::string outputFn = PacBio::BAM::PbbamTestsConfig::GeneratedData_Dir + "/sorted.vcf";
+const std::string inputFn = PacBio::BAM::PbbamTestsConfig::Data_Dir + "/vcf/unsorted.vcf";
+const std::string outputFn = PacBio::BAM::PbbamTestsConfig::GeneratedData_Dir + "/sorted.vcf";
 
-} // namespace VcfSortTests
+}  // namespace VcfSortTests
 
 TEST(VCF_Sort, sorts_input_file)
 {
     const VcfFile file{VcfSortTests::inputFn};
     PacBio::VCF::SortFile(file, VcfSortTests::outputFn);
 
-    const std::vector<std::string> expectedIds{
-        "variant0",
-        "variant5",
-        "variant1",
-        "variant3",
-        "variant4",
-        "variant2"
-    };
+    const std::vector<std::string> expectedIds{"variant0", "variant5", "variant1",
+                                               "variant3", "variant4", "variant2"};
 
-    size_t i= 0;
+    size_t i = 0;
     VcfQuery query{VcfSortTests::outputFn};
-    for (const auto& var : query)
-    {
+    for (const auto& var : query) {
         EXPECT_EQ(expectedIds.at(i), var.Id());
         ++i;
     }
@@ -47,5 +37,3 @@ TEST(VCF_Sort, sorts_input_file)
     // remove temp file
     remove(VcfSortTests::outputFn.c_str());
 }
-
-// clang-format on
